@@ -3,6 +3,56 @@
  * Этот файл подключается последним.
  */
 
+/**
+ * Реализация bind, если таковой нет (для поддержки в IE)
+ */
+if (!Function.prototype.bind) {
+  Function.prototype.bind = function(oThis) {
+    if (typeof this !== 'function') {
+      // closest thing possible to the ECMAScript 5
+      // internal IsCallable function
+      throw new TypeError('Function.prototype.bind - what is trying to be bound is not callable');
+    }
+
+    var aArgs   = Array.prototype.slice.call(arguments, 1),
+        fToBind = this,
+        fNOP    = function() {},
+        fBound  = function() {
+          return fToBind.apply(this instanceof fNOP && oThis
+                 ? this
+                 : oThis,
+                 aArgs.concat(Array.prototype.slice.call(arguments)));
+        };
+
+    fNOP.prototype = this.prototype;
+    fBound.prototype = new fNOP();
+
+    return fBound;
+  };
+}
+
+/**
+ * Необходимо для фикса ошибки "parentNode null or not an object" в IE10
+ */
+Ext.override(Ext.Element, {
+
+    /**
+    * Inserts this element after the passed element in the DOM
+    * @param {Mixed} el The element to insert after
+    * @return {Ext.Element} this
+    *
+    * @overrides  to fix IE issue of "parentNode null or not an object".
+    */
+    insertAfter: function(el){
+        el = Ext.getDom(el);
+        if (el && el.parentNode) {
+            el.parentNode.insertBefore(this.dom, el.nextSibling);
+        }
+        return this;
+    }
+});
+
+
 /**
  * Нужно для правильной работы окна
  */
@@ -464,16 +514,20 @@ var restoreClass = function (readOnly) {
 
 Ext.override(Ext.form.Field, {
     setReadOnly: function (readOnly) {
-        setReadOnlyField.call(this, readOnly);
-        restoreClass.call(this, readOnly);
+        if(!(this.ownerCt && this.ownerCt.readOnly)){
+            setReadOnlyField.call(this, readOnly);
+            restoreClass.call(this, readOnly);
+        }
     }
 });
 
 var setReadOnlyTriggerField = Ext.form.TriggerField.prototype.setReadOnly;
 Ext.override(Ext.form.TriggerField, {
     setReadOnly: function (readOnly) {
-        setReadOnlyTriggerField.call(this, readOnly);
-        restoreClass.call(this, readOnly);
+        if(!(this.ownerCt && this.ownerCt.readOnly)){
+            setReadOnlyTriggerField.call(this, readOnly);
+            restoreClass.call(this, readOnly);
+        }
     }
 });
 
@@ -549,3 +603,28 @@ Ext.override(Ext.grid.GridView, {
         return true;
     }
 });
+
+/**
+* В ExtJS по какой-то причине используется parseInt что приводит к ошибкам
+* при обработке дробных значений
+* было size = side && parseInt(this.getStyle(styles[side]), 10)
+* стало size = side && parseFloat(this.getStyle(styles[side]))
+*/
+Ext.override(Ext.Element, {
+    addStyles : function(sides, styles){
+        var ttlSize = 0,
+            sidesArr = sides.match(/\w/g),
+            side,
+            size,
+            i,
+            len = sidesArr.length;
+        for (i = 0; i < len; i++) {
+            side = sidesArr[i];
+            size = side && parseFloat(this.getStyle(styles[side]));
+            if (size) {
+                ttlSize += Math.abs(size);
+            }
+        }
+        return ttlSize;
+    }
+});
