@@ -1,11 +1,7 @@
-#coding:utf-8
-"""
-Created on 25.02.2010
+# coding: utf-8
+from __future__ import absolute_import
 
-@author: akvarats
-"""
-
-from base import BaseExtControl
+from .base import BaseExtControl
 
 
 #==============================================================================
